@@ -112,20 +112,26 @@ void callforwardingdialog_show (GtkWindow *parent,
 
   gtk_container_add (GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), vbox);
 
-  /* Set dialog insensitive while settings are loaded */
-  hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
-  gtk_widget_set_sensitive (button, FALSE);
-  gtk_widget_set_sensitive (entry, FALSE);
-  gtk_widget_set_sensitive (label, FALSE);
-  gtk_widget_set_sensitive (select_contact, FALSE);
-  gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
-  if (picker != NULL)
+  // NO_AVAIL is only for set, status can't queried
+  if (type == SS_DIVERT_NO_AVAIL)
   {
-    gtk_widget_set_sensitive (picker, FALSE);
+    set_dialog_sensitivity ();
+    gtk_widget_show_all (dialog);
+  } else {
+    /* Set dialog insensitive while settings are loaded */
+    hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
+    gtk_widget_set_sensitive (button, FALSE);
+    gtk_widget_set_sensitive (entry, FALSE);
+    gtk_widget_set_sensitive (label, FALSE);
+    gtk_widget_set_sensitive (select_contact, FALSE);
+    gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
+    if (picker != NULL)
+    {
+      gtk_widget_set_sensitive (picker, FALSE);
+    }
+    gtk_widget_show_all (dialog);
+    callforwarding_get_status (type, callforwarding_status_reply);
   }
-  gtk_widget_show_all (dialog);
-
-  callforwarding_get_status (type, callforwarding_status_reply);
 }
 
 static void set_dialog_sensitivity (void)
